@@ -19,8 +19,10 @@
 #
 ##############################################################################
 
-from record import Record
-from fields import *
+from .exception import RetrofixException
+from .fields import Const, Char, Number, Date, Account, Numeric, Integer
+from .fields import SIGN_POSITIVE
+from .record import Record
 
 # Currency ISO codes:
 #
@@ -230,7 +232,7 @@ def read(data):
         elif Record.valid(current_line, PRESENTER_FOOTER_RECORD):
             record = Record.extract(current_line, PRESENTER_FOOTER_RECORD)
         else:
-            raise Exception('Invalid record: %s' % current_line)
+            raise RetrofixException('Invalid record: %s' % current_line)
         records.append(record)
         current_line = lines.pop(0)
     return records
