@@ -1,7 +1,7 @@
 # encoding: utf8
 ##############################################################################
 #
-#    Copyright (C) 2011-2013 NaN Projectes de Programari Lliure, S.L.
+#    Copyright (C) 2011-2016 NaN Projectes de Programari Lliure, S.L.
 #                            http://www.NaN-tic.com
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -19,8 +19,9 @@
 #
 ##############################################################################
 
-from record import Record
-from .fields import *
+from .exception import RetrofixException
+from .fields import Const, Date, Char, Number, SIGN_12, Numeric, Integer
+from .record import Record
 
 # Currency ISO codes:
 #
@@ -60,11 +61,11 @@ ACCOUNT_HEADER_RECORD = (
 MOVE_RECORD = (
     ( 1,  2, 'record_code', Const('22')),
     ( 3,  4, 'free', Char), # With space. Exceptionally will show bank code
-    ( 7,  4, 'bank_office', Number),
+    ( 7,  4, 'bank_office', Char),
     (11,  6, 'operation_date', Date('%y%m%d')),
     (17,  6, 'value_date', Date('%y%m%d')),
     (23,  2, 'common_concept_code', Number),
-    (25,  3, 'bank_concept_code', Number), # Bank's own concept code
+    (25,  3, 'bank_concept_code', Char), # Bank's own concept code
     (28, 15, 'amount', Numeric(sign=SIGN_12)),
     (43, 10, 'document_number', Number),
     (53, 12, 'reference_1', Char),
@@ -130,7 +131,7 @@ def read(data):
 
     records = []
     if not Record.valid(current_line, ACCOUNT_HEADER_RECORD):
-        raise BaseException('Expected account header record at line %d' %
+        raise RetrofixException('Expected account header record at line %d' %
             (line_count - len(lines)))
 
     record = Record.extract(current_line, ACCOUNT_HEADER_RECORD)
@@ -148,7 +149,7 @@ def read(data):
             records.append(record)
             break
         else:
-            raise BaseException('Invalid data at line %d' %
+            raise RetrofixException('Invalid data at line %d' %
                 (line_count - len(lines)))
         records.append(record)
         current_line = lines.pop(0)
